==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/tools/clangpchmanagerbackend/source/projectpartsinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectpartcontainerv2.h>

namespace ClangBackEnd {

class ProjectPartsInterface
{
public:
    virtual ~ProjectPartsInterface();

    virtual V2::ProjectPartContainers update(V2::ProjectPartContainers &&projectsParts) = 0;
    virtual void remove(const Utils::SmallStringVector &projectPartIds) = 0;
    virtual V2::ProjectPartContainers projects(const Utils::SmallStringVector &projectPartIds) const = 0;
};

} // namespace ClangBackEnd

==> qtcreator_4.8.2.orig.tar.xz: qt-creator-opensource-src-4.8.2/src/tools/clangpchmanagerbackend/source/projectpartsinterface.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectpartcontainerv2.h>

namespace ClangBackEnd {

class ProjectPartsInterface
{
public:
    ProjectPartsInterface() = default;
    ProjectPartsInterface(const ProjectPartsInterface &) = delete;
    ProjectPartsInterface &operator=(const ProjectPartsInterface &) = delete;

    virtual V2::ProjectPartContainers update(V2::ProjectPartContainers &&projectsParts) = 0;
    virtual void remove(const Utils::SmallStringVector &projectPartIds) = 0;
    virtual V2::ProjectPartContainers projects(const Utils::SmallStringVector &projectPartIds) const = 0;

protected:
    ~ProjectPartsInterface() = default;
};

} // namespace ClangBackEnd
